@@ -73,6 +73,22 @@
   (complex (realpart num) (- (imagpart num))))
 
 
+(defparameter *gensym-counter* 1)
+
+(defun gensym (&optional x)
+  (let ((str (make-string-output-stream)))
+    (cond
+      ((stringp x) (write-string x str)
+       (write *gensym-counter* :stream str)
+       (incf *gensym-counter*))
+      ((integerp x) (write-string "G" str)
+       (write x :stream str))
+      ((null x) (write-string "G" str)
+       (write *gensym-counter* :stream str)
+       (incf *gensym-counter*)))
+    (make-symbol (get-output-stream-string str))))
+
+
 (defun first (list) (nth 0 list))
 (defun second (list) (nth 1 list))
 (defun third (list) (nth 2 list))
@@ -206,6 +222,50 @@
   (member-if (complement pred) list))
 
 
+(defun find (obj seq)
+  (find-if (lambda (x) (eql obj x)) seq))
+
+
+(defun find-if (pred seq)
+  (dotimes (i (length seq) nil)
+    (if (funcall pred (elt seq i))
+	(return-from find-if (elt seq i)))))
+
+
+(defun find-if-not (pred seq)
+  (find-if (complement pred) seq))
+
+
+(defun assoc (obj alist)
+  (assoc-if (lambda (x) (eql obj x)) alist))
+
+
+(defun assoc-if (pred alist)
+  (let ((subl alist))
+    (dotimes (i (length alist))
+      (if (funcall pred (car (car subl)))
+	  (return-from assoc-if (car subl)))
+      (setq subl (cdr subl)))))
+
+
+(defun assoc-if-not (pred alist)
+  (assoc-if (complement pred) alist))
+
+
+(defun position (obj seq)
+  (position-if (lambda (x) (eql obj x)) seq))
+
+
+(defun position-if (pred seq)
+  (dotimes (i (length seq) nil)
+    (if (funcall pred (elt seq i))
+	(return-from position-if i))))
+
+
+(defun position-if-not (pred seq)
+  (position-if (complement pred) seq))
+
+
 (defun count (obj seq)
   (let ((ret 0))
     (dotimes (i (length seq))
@@ -364,6 +424,9 @@
 (defun consp (obj)
   (typep obj 'cons))
 
+(defun atom (obj)
+  (typep obj 'atom))
+
 (defun listp (obj)
   (typep obj 'list))
 
@@ -406,6 +469,9 @@
 (defun stringp (obj)
   (typep obj 'string))
 
+(defun hash-table-p (obj)
+  (typep obj 'hash-table))
+
 (defun pathnamep (obj)
   (typep obj 'pathname))
 
