@@ -137,6 +137,7 @@ make_test ("#\\\\", "#\\\\");
 make_test ("#\\|", "#\\|");
 make_test ("#\\newLINE", "#\\Newline");
 make_test ("#\\\n ", "#\\Newline");
+make_test ("#\\Newline", "#\\Newline");
 make_test ("#.\"\"", "\"\"");
 make_test ("#p\".\"", "#P\".\"");
 make_test ("#(1 2 3)", "#(1 2 3)");
@@ -184,12 +185,18 @@ make_test ("(eql #\\A #\\a)", "NIL");
 make_test ("(null 1)", "NIL");
 make_test ("(not nil)", "T");
 make_test ("(cons 1 2)", "(1 . 2)");
+make_test ("(list)", "NIL");
 make_test ("(list 1 2 3)", "(1 2 3)");
 make_test ("(list* 0)", "0");
 make_test ("(list* 0 1 2)", "(0 1 . 2)");
 make_test ("(append ())", "NIL");
 make_test ("(append '(1 2) '(3 4))", "(1 2 3 4)");
 make_test ("(append '(1) (values))", "(1)");
+make_test ("(nconc)", "NIL");
+make_test ("(nconc 0)", "0");
+make_test ("(nconc (list 'a 'b 'c) (list 'd 'e))", "(A B C D E)");
+make_test ("(nconc (list 'a 'b 'c) 'd)", "(A B C . D)");
+make_test ("(nconc (list 'a 'b 'c) NIL (list 'd 'e) NIL 'f)", "(A B C D E . F)");
 make_test ("(let ((a 2)) a)", "2");
 make_test ("(let ((x 0)) x x x)", "0");
 make_test ("(flet ((a () (write \"\"))) (a))", "\"\"\n\"\"");
@@ -322,6 +329,7 @@ make_test ("(typep \"abc\" 'string)", "T");
 make_test ("(typep \"abc\" '(string))", "T");
 make_test ("(typep \"abc\" 'array)", "T");
 make_test ("(typep 0 'string)", "NIL");
+make_test ("(typep (make-hash-table) 'hash-table)", "T");
 make_test ("(typep '(1 2) 'list)", "T");
 make_test ("(typep #(1 2) 'sequence)", "T");
 make_test ("(typep \"\" t)", "T");
@@ -350,6 +358,9 @@ make_test ("(fdefinition 'car)", "#<FUNCTION BUILTIN CAR>");
 make_test ("(funcall (complement #'numberp) \"\")", "T");
 make_test ("(symbol-name 'aaa)", "\"AAA\"");
 make_test ("(symbol-name :bbb)", "\"BBB\"");
+make_test ("(symbol-package 'if)", "#<PACKAGE \"COMMON-LISP\">");
+make_test ("(symbol-package 'ggg)", "#<PACKAGE \"COMMON-LISP-USER\">");
+make_test ("(symbol-package :eee)", "#<PACKAGE \"KEYWORD\">");
 make_test ("(special-operator-p 'if)", "T");
 make_test ("(special-operator-p 'car)", "NIL");
 make_test ("(special-operator-p 'aaa)", "NIL");
@@ -456,9 +467,17 @@ make_test ("(array-row-major-index (make-array '(1 2 3)) 0 0 0)", "0");
 make_test ("(array-row-major-index (make-array '(2 3 4)) 0 0 1)", "1");
 make_test ("(array-row-major-index (make-array '(2 3 4)) 0 2 0)", "8");
 make_test ("(array-row-major-index (make-array '(2 3 4)) 1 0 0)", "12");
+make_test ("(make-hash-table)", "#<HASH-TABLE EQ 0/1024>");
+make_test ("(hash-table-size (make-hash-table))", "1024");
+make_test ("(hash-table-count (make-hash-table))", "0");
+make_test ("(gethash 10 (make-hash-table))", "NIL\nNIL");
+make_test ("(remhash '(1 2) (make-hash-table))", "NIL");
 make_test ("(last '(1 2 3))", "(3)");
 make_test ("(last '(1 2 3) 0)", "NIL");
 make_test ("(last '(1 2 3) 2)", "(2 3)");
+make_test ("(read-line (make-string-input-stream \"hello world\"))", "\"hello world\"\nT");
+make_test ("(read-line (make-string-input-stream \"hello world\n" .
+	   "\"))", "\"hello world\"\nNIL");
 make_test ("(eval '(write \"\"))", "\"\"\n\"\"");
 make_test ("(setq var 10)", "10");
 make_test ("(let ((var 12)) (eval 'var))", "10");
@@ -495,6 +514,20 @@ make_test ("(write-char #\\newline str)", "#\\Newline");
 make_test ("(write '(1 2 3) :stream str)", "(1 2 3)");
 make_test ("(write #(1 2 3) :stream str)", "#(1 2 3)");
 make_test ("(close str)", "T");
+make_test ("(make-string-input-stream \"aaa\")", "#<STREAM ?>");
+make_test ("(defparameter str (make-string-output-stream))", "STR");
+make_test ("(write 'aaa :stream str)", "AAA");
+make_test ("(write \"bbb\" :stream str)", "\"bbb\"");
+make_test ("(write #\\c :stream str)", "#\\c");
+make_test ("(write 100 :stream str)", "100");
+make_test ("(write 1.2 :stream str)", "1.2");
+make_test ("(get-output-stream-string str)", "\"AAA\\\"bbb\\\"#\\\\c1001.2\"");
+make_test ("(get-output-stream-string str)", "\"\"");
+make_test ("(gensym)", "#:G1");
+make_test ("(gensym)", "#:G2");
+make_test ("(gensym 5)", "#:G5");
+make_test ("(gensym \"A\")", "#:A3");
+make_test ("(gensym)", "#:G4");
 make_test ("(second '(0))", "NIL");
 make_test ("(fifth '(0 1 2 3 4))", "4");
 make_test ("(endp '(1 . 2))", "NIL");
@@ -568,11 +601,43 @@ make_test ("(member 5 '(1 2 3))",  "NIL");
 make_test ("(member-if #'evenp '(1 2 3 4))", "(2 3 4)");
 make_test ("(member-if #'listp '(nil))", "(NIL)");
 make_test ("(member-if-not #'evenp '(0 2 4))", "NIL");
+make_test ("(find #\\3 \"012\")", "NIL");
+make_test ("(find #\\3 \"0123\")", "#\\3");
+make_test ("(find-if 'digit-char-p \"0123\")", "#\\0");
+make_test ("(find-if-not 'digit-char-p \"0123\")", "NIL");
+make_test ("(assoc 2 '((0 . 10) (1 . 11) (2 . 12)))", "(2 . 12)");
+make_test ("(assoc 3 '((0 . 10) (1 . 11) (2 . 12)))", "NIL");
+make_test ("(assoc-if 'zerop '((0 . 10) (1 . 11) (2 . 12)))", "(0 . 10)");
+make_test ("(assoc-if-not 'zerop '((0 . 10) (1 . 11) (2 . 12)))", "(1 . 11)");
+make_test ("(position 2 '(3 2 1 0))", "1");
+make_test ("(position 4 '(3 2 1 0))", "NIL");
+make_test ("(position-if 'evenp '(3 2 1 0))", "1");
+make_test ("(position-if 'evenp '(3 1))", "NIL");
+make_test ("(position-if-not #'evenp '(3 1))", "0");
 make_test ("(count #\\a \"abcabc\")", "2");
 make_test ("(count 2 '(1 2 3))", "1");
 make_test ("(count-if #'upper-case-p \"aAbBcCdD\")", "4");
 make_test ("(count-if-not #'evenp #(0 1 2))", "1");
 make_test ("*package*", "#<PACKAGE \"COMMON-LISP-USER\">");
+make_test ("(find-package *package*)", "#<PACKAGE \"COMMON-LISP-USER\">");
+make_test ("(find-package \"CL\")", "#<PACKAGE \"COMMON-LISP\">");
+make_test ("(find-package 'cl-user)", "#<PACKAGE \"COMMON-LISP-USER\">");
+make_test ("(find-package #\\a)", "NIL");
+make_test ("(package-name \"CL\")", "\"COMMON-LISP\"");
+make_test ("(package-name *package*)", "\"COMMON-LISP-USER\"");
+make_test ("(package-nicknames *package*)", "(\"CL-USER\")");
+make_test ("(package-nicknames (symbol-package :fff))", "NIL");
+make_test ("(package-use-list *package*)", "(#<PACKAGE \"COMMON-LISP\">)");
+make_test ("(package-use-list (symbol-package :fff))", "NIL");
+make_test ("(package-used-by-list *package*)", "NIL");
+make_test ("(package-used-by-list (symbol-package 'if))", "(#<PACKAGE \"COMMON-LISP-USER\">)");
+make_test ("(list-all-packages)", "(#<PACKAGE \"COMMON-LISP-USER\"> #<PACKAGE \"COMMON-LISP\"> #<PACKAGE \"KEYWORD\">)");
+make_test ("(make-package \"test\")", "#<PACKAGE \"test\">");
+make_test ("(list-all-packages)", "(#<PACKAGE \"test\"> #<PACKAGE \"COMMON-LISP-USER\"> #<PACKAGE \"COMMON-LISP\"> #<PACKAGE \"KEYWORD\">)");
+make_test ("(in-package \"CL\")", "#<PACKAGE \"COMMON-LISP\">");
+make_test ("*package*", "#<PACKAGE \"COMMON-LISP\">");
+make_test ("(in-package cl-user)", "#<PACKAGE \"COMMON-LISP-USER\">");
+make_test ("*package*", "#<PACKAGE \"COMMON-LISP-USER\">");
 
 
 # arithmetic tests
